==> acl2_8.4dfsg.orig.tar.gz: acl2-8.4dfsg/books/centaur/vl2014/top-doc.lisp <==
; Copyright (C) 2018 Centaur Technology
;
; Contact:
;   Centaur Technology Formal Verification Group
;   7600-C N. Capital of Texas Highway, Suite 300, Austin, TX 78731, USA.
;   http://www.centtech.com/
;
; License: (An MIT/X11-style license)
;
;   Permission is hereby granted, free of charge, to any person obtaining a
;   copy of this software and associated documentation files (the "Software"),
;   to deal in the Software without restriction, including without limitation
;   the rights to use, copy, modify, merge, publish, distribute, sublicense,
;   and/or sell copies of the Software, and to permit persons to whom the
;   Software is furnished to do so, subject to the following conditions:
;
;   The above copyright notice and this permission notice shall be included in
;   all copies or substantial portions of the Software.
;
;   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
;   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
;   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
;   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
;   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
;   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
;   DEALINGS IN THE SOFTWARE.
;
; Original author (this file): Sol Swords <sswords@centtech.com>

(in-package "VL2014")

(include-book "xdoc/archive-matching-topics" :dir :system)
(local
 (progn
   (include-book "doc")
   (include-book "kit/top")
   (include-book "mlib/clean-concats")
   (include-book "lint/use-set")
   (include-book "transforms/clean-selects")
   (include-book "transforms/propagate")
   (include-book "transforms/expr-simp")
   (include-book "transforms/inline")
   (include-book "util/prefix-hash")
   (include-book "centaur/esim/defmodules" :dir :system)))


(xdoc::archive-matching-topics
 (or (str::strprefixp "[books]/centaur/vl2014/" (cdr (assoc :from x)))
     (str::strprefixp "[books]/centaur/esim/stv/stv2c" (cdr (assoc :from x)))
     (equal (cdr (assoc :from x)) "[defxdoc-raw]"))) ;; for topics defined using defxdoc-raw

==> acl2_8.6+dfsg.orig.tar.gz: acl2-8.6+dfsg/books/centaur/vl2014/top-doc.lisp <==
; Copyright (C) 2018 Centaur Technology
;
; Contact:
;   Centaur Technology Formal Verification Group
;   7600-C N. Capital of Texas Highway, Suite 300, Austin, TX 78731, USA.
;   http://www.centtech.com/
;
; License: (An MIT/X11-style license)
;
;   Permission is hereby granted, free of charge, to any person obtaining a
;   copy of this software and associated documentation files (the "Software"),
;   to deal in the Software without restriction, including without limitation
;   the rights to use, copy, modify, merge, publish, distribute, sublicense,
;   and/or sell copies of the Software, and to permit persons to whom the
;   Software is furnished to do so, subject to the following conditions:
;
;   The above copyright notice and this permission notice shall be included in
;   all copies or substantial portions of the Software.
;
;   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
;   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
;   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
;   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
;   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
;   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
;   DEALINGS IN THE SOFTWARE.
;
; Original author (this file): Sol Swords <sswords@centtech.com>

(in-package "VL2014")

(include-book "xdoc/archive-matching-topics" :dir :system)
(local
 (progn
   (include-book "doc")
   (include-book "kit/top")
   (include-book "mlib/clean-concats")
   (include-book "lint/use-set")
   (include-book "transforms/clean-selects")
   (include-book "transforms/propagate")
   (include-book "transforms/expr-simp")
   (include-book "transforms/inline")
   (include-book "util/prefix-hash")
   (include-book "centaur/esim/defmodules" :dir :system)))


(xdoc::archive-matching-topics
 (or (str::strprefixp "centaur/vl2014/" (cdr (assoc :from x)))
     (str::strprefixp "centaur/esim/stv/stv2c" (cdr (assoc :from x)))
     (equal (cdr (assoc :from x)) "[defxdoc-raw]"))) ;; for topics defined using defxdoc-raw
